@@ -1,12 +1,30 @@
 package Sah::Schema::dirname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-26'; # DATE
+our $DATE = '2021-07-17'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [str => {
     summary => 'Filesystem directory name',
+    description => <<'_',
+
+This schema is basically string with some checks and prefilters. Why use this
+schema instead of plain ol' str? Mainly to give you the ability to change tilde
+to user's home directory, e.g. `~/foo` into `/home/someuser/foo`. Normally this
+expansion is done by a Unix shell, but sometimes your program receives an
+unexpanded path, e.g. when you get it from some config file.
+
+See also more OS-specific schemas like `dirname::unix`, which adds some more
+checks (e.g. filename cannot contain forward slash and each component cannot be
+longer than 255 characters) and preprocessing (e.g. stripping extraneous slashes
+like `foo//bar` into `foo/bar`.
+
+What's the difference between this schema and `filename`? The default completion
+rule. This schema's completion by default only includes directories.
+
+_
+
     min_len => 1,
 
     'x.completion' => ['dirname'],
@@ -38,7 +56,7 @@ Sah::Schema::dirname - Filesystem directory name
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2020-08-26.
+This document describes version 0.016 of Sah::Schema::dirname (from Perl distribution Sah-Schemas-Path), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
@@ -109,6 +127,22 @@ Sample data:
 
  "foo/bar"  # valid
 
+=head1 DESCRIPTION
+
+This schema is basically string with some checks and prefilters. Why use this
+schema instead of plain ol' str? Mainly to give you the ability to change tilde
+to user's home directory, e.g. C<~/foo> into C</home/someuser/foo>. Normally this
+expansion is done by a Unix shell, but sometimes your program receives an
+unexpanded path, e.g. when you get it from some config file.
+
+See also more OS-specific schemas like C<dirname::unix>, which adds some more
+checks (e.g. filename cannot contain forward slash and each component cannot be
+longer than 255 characters) and preprocessing (e.g. stripping extraneous slashes
+like C<foo//bar> into C<foo/bar>.
+
+What's the difference between this schema and C<filename>? The default completion
+rule. This schema's completion by default only includes directories.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Path>.
@@ -131,7 +165,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
